# pyctest

Release: pyctest 0.0.3
----------------------

- Author: Jonathan R. Madsen
- Date: Fri Jun 15 2018

  - Fixed support for CMake < 3.10 (error about command: "include_guard")
  - Removed official support from Python 3.4
  - Disabled strictStrings on Windows causing error
  - Force GNU compiler on Linux
  - Set max compile procs to 8

Release: pyctest 0.0.2
----------------------

- Author: Jonathan R. Madsen
- Date: Thu Jun 14 2018

  - Added Basic examples
  - updated REAME
  - fixes some packaging issues
  - cleaned up some stdout debugging

Release: pyctest 0.0.1
----------------------

- Author: Jonathan R. Madsen
- Date: Thu Jun 14 2018

  - Initial release of pyctest
